@@ -27,9 +27,9 @@ import (
 	"github.com/banzaicloud/k8s-objectmatcher/patch"
 	"github.com/coreos/pkg/capnslog"
 	"github.com/pkg/errors"
+	monitoringv1 "github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring/v1"
 	cephv1 "github.com/rook/rook/pkg/apis/ceph.rook.io/v1"
 	"github.com/rook/rook/pkg/clusterd"
-	"github.com/rook/rook/pkg/daemon/ceph/client"
 	cephclient "github.com/rook/rook/pkg/daemon/ceph/client"
 	"github.com/rook/rook/pkg/operator/ceph/cluster/mon"
 	"github.com/rook/rook/pkg/operator/ceph/config"
@@ -162,15 +162,6 @@ func (c *Cluster) Start() error {
 			}
 			logger.Infof("deployment for mgr %s already exists. updating if needed", resourceName)
 
-			// During an upgrade, make sure the server_addr setting is cleared or else the prometheus
-			// service may not be able to bind to the pod ip anymore, as was the setting in 4.7 and prior.
-			// This is only needed for 4.8 since upgrades to later clusters will always use the default.
-			logger.Info("ensuring the prometheus server_port is unset to binding to the localhost by default")
-			_, err = client.SetConfig(c.context, c.clusterInfo, fmt.Sprintf("mgr.%s", daemonID), fmt.Sprintf("mgr/prometheus/%s/server_addr", daemonID), "", false)
-			if err != nil {
-				logger.Warningf("failed to unset the prometheus server_port. %v", err)
-			}
-
 			if err := updateDeploymentAndWait(c.context, c.clusterInfo, d, config.MgrType, mgrConfig.DaemonID, c.spec.SkipUpgradeChecks, false); err != nil {
 				logger.Errorf("failed to update mgr deployment %q. %v", resourceName, err)
 			}
@@ -191,10 +182,28 @@ func (c *Cluster) Start() error {
 	// check if any extra mgrs need to be removed
 	c.removeExtraMgrs(daemonIDs)
 
-	if len(daemonIDs) == 1 {
-		// Only reconcile the mgr services in the operator if there is a single mgr.
-		// If there are multiple mgrs they will be managed by the mgr sidecar.
-		if err := c.reconcileService(daemonIDs[0]); err != nil {
+	activeMgr := daemonIDs[0]
+	if len(daemonIDs) > 1 {
+		// When multiple mgrs are running, the mgr sidecar for the active mgr
+		// will create the services. However, the sidecar will only reconcile all
+		// the services when the active mgr changes. Here as part of the regular reconcile
+		// we trigger reconciling all the services to ensure they are current.
+		activeMgr, err = c.getActiveMgr()
+		if err != nil || activeMgr == "" {
+			activeMgr = ""
+			logger.Infof("cannot reconcile mgr services, no active mgr found. err=%v", err)
+		}
+
+		// reconcile mgr PDB
+		if err := c.reconcileMgrPDB(); err != nil {
+			return errors.Wrap(err, "failed to reconcile mgr PDB")
+		}
+	} else {
+		// delete MGR PDB as the count is less than 2
+		c.deleteMgrPDB()
+	}
+	if activeMgr != "" {
+		if err := c.reconcileServices(activeMgr); err != nil {
 			return errors.Wrap(err, "failed to enable mgr services")
 		}
 	}
@@ -233,9 +242,9 @@ func (c *Cluster) removeExtraMgrs(daemonIDs []string) {
 	}
 }
 
-// ReconcileMultipleServices reconciles the services if the active mgr is the one running
+// ReconcileActiveMgrServices reconciles the services if the active mgr is the one running
 // in the sidecar
-func (c *Cluster) ReconcileMultipleServices(daemonNameToUpdate string, mgrStatSupported bool) error {
+func (c *Cluster) ReconcileActiveMgrServices(daemonNameToUpdate string) error {
 	// If the services are already set to this daemon, no need to attempt to update
 	svc, err := c.context.Clientset.CoreV1().Services(c.clusterInfo.Namespace).Get(context.TODO(), AppName, metav1.GetOptions{})
 	if err != nil {
@@ -249,23 +258,9 @@ func (c *Cluster) ReconcileMultipleServices(daemonNameToUpdate string, mgrStatSu
 		logger.Infof("mgr service currently set to %q, checking if need to update to %q", currentDaemon, daemonNameToUpdate)
 	}
 
-	var activeName string
-	// mgrStatSupported is a flag instead of calling c.clusterInfo.CephVersion.IsAtLeastPacific() directly since we're inside the sidecar
-	// where the cephVersion is not directly available
-	if mgrStatSupported {
-		// The preferred way to query the active mgr is "ceph mgr stat", which is only available in pacific
-		mgrStat, err := cephclient.CephMgrStat(c.context, c.clusterInfo)
-		if err != nil {
-			return errors.Wrap(err, "failed to get mgr stat for the active mgr")
-		}
-		activeName = mgrStat.ActiveName
-	} else {
-		// The legacy way to query the active mgr is with the verbose "ceph mgr dump"
-		mgrMap, err := cephclient.CephMgrMap(c.context, c.clusterInfo)
-		if err != nil {
-			return errors.Wrap(err, "failed to get mgr map for the active mgr")
-		}
-		activeName = mgrMap.ActiveName
+	activeName, err := c.getActiveMgr()
+	if err != nil {
+		return err
 	}
 	if activeName == "" {
 		return errors.New("active mgr not found")
@@ -275,11 +270,30 @@ func (c *Cluster) ReconcileMultipleServices(daemonNameToUpdate string, mgrStatSu
 		return nil
 	}
 
-	return c.reconcileService(activeName)
+	return c.reconcileServices(activeName)
+}
+
+func (c *Cluster) getActiveMgr() (string, error) {
+	// The preferred way to query the active mgr is "ceph mgr stat", which is only available in pacific or newer
+	if c.clusterInfo.CephVersion.IsAtLeastPacific() {
+		mgrStat, err := cephclient.CephMgrStat(c.context, c.clusterInfo)
+		if err != nil {
+			return "", errors.Wrap(err, "failed to get mgr stat for the active mgr")
+		}
+		return mgrStat.ActiveName, nil
+	}
+
+	// The legacy way to query the active mgr is with the verbose "ceph mgr dump"
+	mgrMap, err := cephclient.CephMgrMap(c.context, c.clusterInfo)
+	if err != nil {
+		return "", errors.Wrap(err, "failed to get mgr map for the active mgr")
+	}
+
+	return mgrMap.ActiveName, nil
 }
 
 // reconcile the services, if the active mgr is not detected, use the default mgr
-func (c *Cluster) reconcileService(activeDaemon string) error {
+func (c *Cluster) reconcileServices(activeDaemon string) error {
 	logger.Infof("setting services to point to mgr %q", activeDaemon)
 
 	if err := c.configureDashboardService(activeDaemon); err != nil {
@@ -462,6 +476,9 @@ func (c *Cluster) EnableServiceMonitor(activeDaemon string) error {
 	}
 	serviceMonitor.Spec.NamespaceSelector.MatchNames = []string{c.clusterInfo.Namespace}
 	serviceMonitor.Spec.Selector.MatchLabels = c.selectorLabels(activeDaemon)
+
+	applyMonitoringLabels(c, serviceMonitor)
+
 	if _, err = k8sutil.CreateOrUpdateServiceMonitor(serviceMonitor); err != nil {
 		return errors.Wrap(err, "service monitor could not be enabled")
 	}
@@ -501,3 +518,24 @@ func IsModuleInSpec(modules []cephv1.Module, moduleName string) bool {
 
 	return false
 }
+
+// ApplyMonitoringLabels function adds the name of the resource that manages
+// cephcluster, as a label on the ceph metrics
+func applyMonitoringLabels(c *Cluster, serviceMonitor *monitoringv1.ServiceMonitor) {
+	if c.spec.Labels != nil {
+		if monitoringLabels, ok := c.spec.Labels["monitoring"]; ok {
+			if managedBy, ok := monitoringLabels["rook.io/managedBy"]; ok {
+				relabelConfig := monitoringv1.RelabelConfig{
+					TargetLabel: "managedBy",
+					Replacement: managedBy,
+				}
+				serviceMonitor.Spec.Endpoints[0].RelabelConfigs = append(
+					serviceMonitor.Spec.Endpoints[0].RelabelConfigs, &relabelConfig)
+			} else {
+				logger.Info("rook.io/managedBy not specified in monitoring labels")
+			}
+		} else {
+			logger.Info("monitoring labels not specified")
+		}
+	}
+}
